/****************************************************************************
File: 	 rp2.h
Purpose: Device driver header file.
Project: RocketPort Infinity/Express
OS: 	 FreeBSD 5
Company: Comtrol Corporation
*****************************************************************************
Copyright 2008 Comtrol Corporation. All rights reserved.
*****************************************************************************/

#ifndef _RP2_DRIVER_H_
#define _RP2_DRIVER_H_ 

//#define RCKT_DEBUG
#ifdef  RCKT_DEBUG
#define DBGPRINT0(str)    printf(str)
#define DBGPRINT1(str, f) printf(str, f)
#define DBGPRINT2(str, f, g) printf(str, f, g)
#else
#define DBGPRINT0(str) 
#define DBGPRINT1(str, f) 
#define DBGPRINT2(str, f, g) 
#endif

#ifndef FIFO_SIZE
  #define FIFO_SIZE 512       /*  FIFO size for both TX and RX FIFO's */
#endif

/*
 *  Minor number encodes the Uit (board number 0 - 3), Callout/normal and Port number (0-31).
 *  .... .... .... ..UU .... .... CPPP PPPP
 */
#define UNIT_MASK		0x030000
#define PORT_MASK		0x00007F
#define CALLOUT_MASK		0x80
#define	MINOR_TO_UNIT(mynor)	(((mynor) & UNIT_MASK)>>16)
#define MINOR_TO_PORT(mynor)	((mynor) & PORT_MASK)
#define IS_CALLOUT(dev) 	(minor(dev) & CALLOUT_MASK)

/*
 * Rocketport Infinity custom ioctl
 */
#define	RP2_IOCTL_SETIFMODE _IOW('t', 255, int)  //  Equals 0x800474FF
#define IFMODE_RS232  0x1
#define IFMODE_RS422  0x2
#define IFMODE_RS485  0x4

#define MAX_NUMBEROF_BOARDS 4 
#define MAX_PORTS_PER_BOARD 32
#define MAX_NUMBEROF_PORTS  (MAX_NUMBEROF_BOARDS * MAX_PORTS_PER_BOARD)
#define MAX_CANON_BUFSIZE 160

/*  Flow control defines  */
#define FLOW_CONTROL_NONE    0
#define FLOW_CONTROL_RTSCTS  1
#define FLOW_CONTROL_XONXOFF 2
#define FLOW_CONTROL_DTRDSR  3

#ifndef NULL
#define NULL 0
#endif

#define NUMBEROF_BAUDS 20

#define COMTROL_VENDOR_ID 0x11fe

/*  Rocketport Infinity Models - This is also the PCI Device ID       */
#define RP2_MODEL_INTF_32    0x0041  /* External I/F 32 port  */
#define RP2_MODEL_INTF_8     0x0042  /* External I/F 8 port  */
#define RP2_MODEL_INTF_16    0x0043  /* External I/F 16 port  */
#define RP2_MODEL_DB9_4      0x0044  /* DB9 4 port  */
#define RP2_MODEL_DB9_8      0x0045  /* DB9 8 port  */
#define RP2_MODEL_SMPTE_8    0x0052  /* SMPTE 8 port  */

#define RP2_EXPRESS_MODEL_RJ45_8     0x0060  /* RJ45 8 port  */
#define RP2_EXPRESS_MODEL_INTF_32    0x0061  /* External I/F 32 port  */
#define RP2_EXPRESS_MODEL_INTF_8     0x0062  /* External I/F 8 port  */
#define RP2_EXPRESS_MODEL_INTF_16    0x0063  /* External I/F 16 port  */
#define RP2_EXPRESS_MODEL_DB9_4      0x0064  /* DB9 4 port  */
#define RP2_EXPRESS_MODEL_DB9_8      0x0065  /* DB9 8 port  */
#define RP2_EXPRESS_MODEL_INTF_4     0x0066  /* External I/F 4 port  */
#define RP2_EXPRESS_MODEL_SMPTE_8    0x0072  /* SMPTE 8 port  */

typedef struct {
    int termiosBaud;
    int baud;
    int prescale;
    int divisor;
} baudTable_t;

typedef struct {
	unsigned int model;
	char modelString[80];
	unsigned int numPorts;
	int has_2nd_asic;
} comtrolModelInfo_t;

/*************************************************************************
 *
 *  Channel structure type definition, one per serial port.
 *
 *************************************************************************/

typedef struct
{
    int Present;         /* Indicates port is found and init'd */
    int channelNumber;   /*  The ASIC channel number (0-31) */
    int portNumber;      /* The tty port number xx = 0 - 127 /dev/ttyRPIxx */

    struct tty *rp2_tty;

    struct cdev *dev0;             /*  The ttyRPIxx device */
    struct cdev *dev1;             /*  The cuaRPIxx device */

    struct termios it_in;          /*  Initial state in/out termios values */
    struct termios it_out;

    unsigned char *pBaseRegister;  /*  Base ptr to port registers */
    unsigned char *ucodeAddr;      /*  Base ptr to the channel's Receive Processor microcode. */

    int rp_restart;  /* A pair of ints acting as low water marks, used to decide if the  */
    int rp_fifo_lw;  /* TX FIFO has room for more bytes */

    int rp_xmit_stopped;
    unsigned char TxBuf[FIFO_SIZE];
} CHANNEL_T;


/*************************************************************************
 *
 *  Controller structure type definition, one per card.  Contains 32 CHANNEL_T
 *  structs, 1 per serial port.
 *
 *************************************************************************/
typedef struct
{
    CHANNEL_T channel[MAX_PORTS_PER_BOARD];  /*  One channel structure per serial port */

    comtrolModelInfo_t *rocketModel;  /*  Model information */
    int has_2nd_asic;                 /*  Set if board has 2 Unity ASICs */
    device_t dev;                     /*  The device struct associated with this card */

    int rid0;                         /* Resource IDs and structs associated with the PCI */
    int rid1;                         /* memory mapped regions */

    struct resource *pciResource0;
    struct resource *pciResource1;

    unsigned char *pBasePciRegion0;                   /*  Base memory address region 0 */
    unsigned char *pBasePciMemory;                    /*  Base memory address region 1 */
} CONTROLLER_T;

#endif
